
import React from 'react';
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Textarea } from "@/components/ui/textarea";
import { Mail, MapPin, Phone } from 'lucide-react';
import { useToast } from '@/components/ui/use-toast';

const ContactSection = () => {
  const { toast } = useToast();

  const handleSubmit = (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    // Here you would typically send the form data to a server
    toast({
      title: "Message Sent!",
      description: "We'll get back to you within 24 hours.",
    });
    console.log("Get in Touch");

  };

  return (
    <section id="contact" className="lg:py-20 md:p-12 p-6 bg-white">
      <div className="container mx-auto">
        <div className="text-center lg:mb-12 mb-6">
          <h2 className="text-3xl md:text-4xl font-display font-bold mb-4 text-gray-900">
            Plan Your Dream Trip
          </h2>
          <p className="text-lg text-gray-600 max-w-2xl mx-auto">
            Ready for an unforgettable Sri Lankan adventure? Contact us to start planning your customized tour.
          </p>
        </div>
        
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12">
          <div className="bg-gray-50 p-8 rounded-lg">
            <h3 className="text-2xl font-bold mb-6">Get in Touch</h3>
            <form onSubmit={handleSubmit} className="space-y-4">
              <div className="grid grid-cols-1 md:grid-cols-2 gap-4">
                <div>
                  <label htmlFor="name" className="block text-sm font-medium mb-1">Name</label>
                  <Input id="name" placeholder="Your Name" required />
                </div>
                <div>
                  <label htmlFor="email" className="block text-sm font-medium mb-1">Email</label>
                  <Input id="email" type="email" placeholder="your.email@example.com" required />
                </div>
              </div>
              
              <div>
                <label htmlFor="subject" className="block text-sm font-medium mb-1">Subject</label>
                <Input id="subject" placeholder="What are you interested in?" required />
              </div>
              
              <div>
                <label htmlFor="message" className="block text-sm font-medium mb-1">Message</label>
                <Textarea id="message" placeholder="Tell us about your travel plans..." className="min-h-[120px]" required />
              </div>
              
              <Button type="submit" className="rounded-full w-full md:w-auto px-8">
                Send Message
              </Button>
            </form>
          </div>
          
          <div className="flex flex-col justify-between">
            <div>
              <h3 className="text-2xl font-bold mb-6">Contact Information</h3>
              <div className="space-y-6">
                <div className="flex items-start">
                  <Phone size={24} className="text-primary mr-4 flex-shrink-0" />
                  <div>
                    <h4 className="font-medium text-gray-900">Phone</h4>
                    <p className="text-gray-600">+94774018278</p>
                  </div>
                </div>
                
                <div className="flex items-start">
                  <Mail size={24} className="text-primary mr-4 flex-shrink-0" />
                  <div>
                    <h4 className="font-medium text-gray-900">Email</h4>
                    <p className="text-gray-600">info@greenisletourssrilanka.com</p>
                    <p className="text-gray-600">greenisletours@gmail.com</p>
                  </div>
                </div>
                
                <div className="flex items-start">
                  <MapPin size={24} className="text-primary mr-4 flex-shrink-0" />
                  <div>
                    <h4 className="font-medium text-gray-900">Office</h4>
                    <p className="text-gray-600">Kalamulla,</p>
                    <p className="text-gray-600">Kalutara, Sri Lanka</p>
                  </div>
                </div>
              </div>
            </div>
            
            <div className="mt-8 p-6 bg-primary/5 rounded-lg">
              <h4 className="font-bold text-lg mb-2">Quick Response Guarantee</h4>
              <p className="text-gray-600">
                We pride ourselves on fast response times. Contact us today and we'll get back to you within 24 hours to start planning your perfect Sri Lankan adventure.
              </p>
            </div>
          </div>
        </div>
      </div>
    </section>
  );
};

export default ContactSection;
